Slice

Struct Slice 

pub struct Slice(/* private fields */);

Implementations

Source

impl Slice

pub fn from_layout(layout: Layout) -> Self

Creates a full slice of the same mode as a Layout.

pub fn is_full(&self) -> bool

Returns true if the slice contains only full axes.